@@ -57,8 +57,8 @@ void RemoveAdmin(
 		Fn<void()> onFail) {
 	const auto newRights = MTP_chatAdminRights(MTP_flags(0));
 	channel->session().api().request(MTPchannels_EditAdmin(
-		channel->inputChannel,
-		user->inputUser,
+		channel->inputChannel(),
+		user->inputUser(),
 		newRights,
 		MTP_string(QString())
 	)).done([=](const MTPUpdates &result) {
@@ -81,8 +81,8 @@ void AddChatParticipant(
 		Fn<void()> onDone,
 		Fn<void()> onFail) {
 	chat->session().api().request(MTPmessages_AddChatUser(
-		chat->inputChat,
-		user->inputUser,
+		chat->inputChat(),
+		user->inputUser(),
 		MTP_int(kForwardMessagesOnAdd)
 	)).done([=](const MTPmessages_InvitedUsers &result) {
 		const auto &data = result.data();
@@ -111,8 +111,8 @@ void SaveChatAdmin(
 		Fn<void()> onFail,
 		bool retryOnNotParticipant = true) {
 	chat->session().api().request(MTPmessages_EditChatAdmin(
-		chat->inputChat,
-		user->inputUser,
+		chat->inputChat(),
+		user->inputUser(),
 		MTP_bool(isAdmin)
 	)).done([=] {
 		chat->applyEditAdmin(user, isAdmin);
@@ -150,8 +150,8 @@ void SaveChannelAdmin(
 		Fn<void()> onDone,
 		Fn<void()> onFail) {
 	channel->session().api().request(MTPchannels_EditAdmin(
-		channel->inputChannel,
-		user->inputUser,
+		channel->inputChannel(),
+		user->inputUser(),
 		AdminRightsToMTP(newRights),
 		MTP_string(rank)
 	)).done([=](const MTPUpdates &result) {
@@ -175,8 +175,8 @@ void SaveChatParticipantKick(
 		Fn<void()> onFail) {
 	chat->session().api().request(MTPmessages_DeleteChatUser(
 		MTP_flags(0),
-		chat->inputChat,
-		user->inputUser
+		chat->inputChat(),
+		user->inputUser()
 	)).done([=](const MTPUpdates &result) {
 		chat->session().api().applyUpdates(result);
 		if (onDone) {
@@ -1515,7 +1515,7 @@ void ParticipantsBoxController::loadMoreRows() {
 	const auto participantsHash = uint64(0);
 
 	_loadRequestId = _api.request(MTPchannels_GetParticipants(
-		channel->inputChannel,
+		channel->inputChannel(),
 		filter,
 		MTP_int(_offset),
 		MTP_int(perPage),
@@ -1686,11 +1686,11 @@ base::unique_qptr<Ui::PopupMenu> ParticipantsBoxController::rowContextMenu(
 			auto text = phrase(
 				tr::now,
 				lt_user,
-				Ui::Text::Bold(by->name()),
+				tr::bold(by->name()),
 				lt_date,
-				Ui::Text::Bold(
+				tr::bold(
 					langDateTimeFull(base::unixtime::parse(since))),
-				Ui::Text::WithEntities);
+				tr::marked);
 			auto button = base::make_unique_q<Ui::Menu::MultilineAction>(
 				result->menu(),
 				result->st().menu,
@@ -1698,7 +1698,7 @@ base::unique_qptr<Ui::PopupMenu> ParticipantsBoxController::rowContextMenu(
 				st::historyHasCustomEmojiPosition,
 				std::move(text));
 			if (const auto n = _navigation) {
-				button->setClickedCallback([=] {
+				button->setActionTriggered([=] {
 					n->parentController()->show(PrepareShortInfoBox(by, n));
 				});
 			}
@@ -1902,6 +1902,9 @@ void ParticipantsBoxController::editRestrictedDone(
 
 void ParticipantsBoxController::kickParticipant(not_null<PeerData*> participant) {
 	const auto user = participant->asUser();
+	if (user && user->isInaccessible()) {
+		return kickParticipantSure(participant);
+	}
 	const auto text = ((_peer->isChat() || _peer->isMegagroup())
 		? tr::lng_profile_sure_kick
 		: tr::lng_profile_sure_kick_channel)(
@@ -2128,7 +2131,12 @@ auto ParticipantsBoxController::computeType(
 		: (user && _additional.adminRights(user).has_value())
 		? Rights::Admin
 		: Rights::Normal;
-	result.adminRank = user ? _additional.adminRank(user) : QString();
+	result.canRemove = _additional.canRemoveParticipant(participant)
+		&& user
+		&& user->isInaccessible();
+	if (!result.canRemove) {
+		result.adminRank = user ? _additional.adminRank(user) : QString();
+	}
 	return result;
 }
 
@@ -2209,7 +2217,7 @@ void ParticipantsBoxController::subscribeToCreatorChange(
 		const auto weak = base::make_weak(this);
 		const auto api = &channel->session().api();
 		api->request(MTPchannels_GetParticipants(
-			channel->inputChannel,
+			channel->inputChannel(),
 			MTP_channelParticipantsRecent(),
 			MTP_int(0), // offset
 			MTP_int(channel->session().serverConfig().chatSizeMax),
@@ -2356,7 +2364,7 @@ bool ParticipantsBoxSearchController::loadMoreRows() {
 	const auto participantsHash = uint64(0);
 
 	_requestId = _api.request(MTPchannels_GetParticipants(
-		_channel->inputChannel,
+		_channel->inputChannel(),
 		filter,
 		MTP_int(_offset),
 		MTP_int(perPage),
