@@ -35,6 +35,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "ui/painter.h"
 #include "ui/vertical_list.h"
 #include "window/section_widget.h"
+#include "window/themes/window_theme.h"
 #include "window/window_session_controller.h"
 #include "styles/style_boxes.h"
 #include "styles/style_chat.h"
@@ -134,21 +135,26 @@ void AddMessage(
 			rightSize.height()).translated(st::settingsReactionCornerSkip);
 	};
 
+	using ThemePtr = std::unique_ptr<Ui::ChatTheme>;
+	const auto theme = widget->lifetime().make_state<ThemePtr>(
+		Window::Theme::DefaultChatThemeOn(widget->lifetime()));
 	widget->paintRequest(
 	) | rpl::on_next([=](const QRect &rect) {
+		Painter p(widget);
+		p.setClipRect(rect);
 		Window::SectionWidget::PaintBackground(
-			controller,
-			controller->defaultChatTheme().get(), // #TODO themes
-			widget,
+			p,
+			theme->get(),
+			QSize(widget->width(), widget->window()->height()),
 			rect);
 
-		Painter p(widget);
 		auto hq = PainterHighQualityEnabler(p);
 		const auto theme = controller->defaultChatTheme().get();
 		auto context = theme->preparePaintContext(
 			state->style.get(),
 			widget->rect(),
 			widget->rect(),
+			widget->rect(),
 			controller->isGifPausedAtLeastFor(
 				Window::GifPauseReason::Layer));
 		context.outbg = view->hasOutLayout();
@@ -330,6 +336,8 @@ void AddReactionAnimatedIcon(
 			return true;
 		};
 		if (check(state->select) && check(state->appear)) {
+			state->select.icon->setCustomEndFrame(1);
+			state->select.icon->animate([] {});
 			state->loadingLifetime.destroy();
 		}
 	}, state->loadingLifetime);
@@ -353,6 +361,11 @@ void AddReactionAnimatedIcon(
 		}
 		if (appear && appear->animating()) {
 			paintFrame(appear);
+			if (appear->frameIndex() == appear->framesCount() - 1) {
+				if (const auto select = state->select.icon.get()) {
+					select->setCustomEndFrame(select->framesCount() - 1);
+				}
+			}
 		} else if (const auto select = state->select.icon.get()) {
 			paintFrame(select);
 		}
