@@ -1360,7 +1360,7 @@ void Panel::subscribeToChanges(not_null<Data::GroupCall*> real) {
 				? tr::lng_group_call_recording_stopped_channel
 				: tr::lng_group_call_recording_stopped))(
 				tr::now,
-				Ui::Text::RichLangValue));
+				tr::rich));
 	}, lifetime());
 	validateRecordingMark(real->recordStartDate() != 0);
 
@@ -2123,6 +2123,7 @@ void Panel::trackControl(Ui::RpWidget *widget, rpl::lifetime &lifetime) {
 					trackControlOver(widget, true);
 				}
 			});
+			toggleWideControls(true);
 		} else if (type == QEvent::Leave) {
 			*over = false;
 			crl::on_main(widget, [=] {
@@ -2130,6 +2131,7 @@ void Panel::trackControl(Ui::RpWidget *widget, rpl::lifetime &lifetime) {
 					trackControlOver(widget, false);
 				}
 			});
+			toggleWideControls(false);
 		}
 	}, lifetime);
 }
@@ -2150,7 +2152,6 @@ void Panel::trackControlOver(not_null<Ui::RpWidget*> control, bool over) {
 	} else {
 		Ui::Integration::Instance().unregisterLeaveSubscription(control);
 	}
-	toggleWideControls(over);
 }
 
 void Panel::showStickedTooltip() {
