@@ -457,8 +457,8 @@ void SettingsBox(
 									? tr::lng_group_call_mac_input()
 									: tr::lng_group_call_mac_accessibility())
 							) | rpl::map([](QString a, QString b) {
-								auto result = Ui::Text::RichLangValue(a);
-								result.append("\n\n").append(Ui::Text::RichLangValue(b));
+								auto result = tr::rich(a);
+								result.append("\n\n").append(tr::rich(b));
 								return result;
 							}),
 							st::groupCallBoxLabel),
@@ -694,7 +694,7 @@ void SettingsBox(
 			state->requestId = session->api().request(
 				MTPphone_GetGroupCallStreamRtmpUrl(
 					MTP_flags(0),
-					peer->input,
+					peer->input(),
 					MTP_bool(true)
 			)).done([=](const MTPphone_GroupCallStreamRtmpUrl &result) {
 				auto data = result.match([&](
@@ -767,19 +767,21 @@ void SettingsBox(
 		Ui::AddSkip(layout);
 	}
 	if (rtmp) {
-		const auto volumeItem = layout->add(
-			object_ptr<MenuVolumeItem>(
-				layout,
-				st::groupCallVolumeSettings,
-				st::groupCallVolumeSettingsSlider,
-				call->otherParticipantStateValue(
-				) | rpl::filter([=](const Group::ParticipantState &data) {
-					return data.peer == peer;
-				}),
-				call->rtmpVolume(),
-				Group::kMaxVolume,
-				false,
-				st::groupCallVolumeSettingsPadding));
+		const auto fakeMenu = layout->add(object_ptr<Ui::Menu::Menu>(
+			layout,
+			st::groupCallVolumeSettings));
+		auto volumeItem = base::make_unique_q<MenuVolumeItem>(
+			fakeMenu,
+			st::groupCallVolumeSettings,
+			st::groupCallVolumeSettingsSlider,
+			call->otherParticipantStateValue(
+			) | rpl::filter([=](const Group::ParticipantState &data) {
+				return data.peer == peer;
+			}),
+			call->rtmpVolume(),
+			Group::kMaxVolume,
+			false,
+			st::groupCallVolumeSettingsPadding);
 
 		const auto toggleMute = crl::guard(layout, [=](bool m, bool local) {
 			if (call) {
@@ -809,6 +811,8 @@ void SettingsBox(
 		) | rpl::on_next([=](int volume) {
 			changeVolume(volume, true);
 		}, volumeItem->lifetime());
+
+		fakeMenu->addAction(std::move(volumeItem));
 	}
 
 	if (call->canManage()) {
