@@ -7,6 +7,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 */
 #include "chat_helpers/emoji_list_widget.h"
 
+#include "window/window_media_preview.h"
 #include "api/api_peer_photo.h"
 #include "apiwrap.h"
 #include "base/unixtime.h"
@@ -46,10 +47,12 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "emoji_suggestions_helper.h"
 #include "main/main_session.h"
 #include "main/main_session_settings.h"
+#include "mainwidget.h"
 #include "core/core_settings.h"
 #include "core/application.h"
 #include "settings/settings_premium.h"
 #include "window/window_session_controller.h"
+#include "window/window_controller.h"
 #include "styles/style_chat_helpers.h"
 #include "styles/style_menu_icons.h"
 
@@ -480,6 +483,8 @@ EmojiListWidget::EmojiListWidget(
 , _features(descriptor.features)
 , _onlyUnicodeEmoji(descriptor.mode == Mode::PeerTitle)
 , _mode(_onlyUnicodeEmoji ? Mode::Full : descriptor.mode)
+, _mediaPreviewParent(descriptor.mediaPreviewParent)
+, _mediaPreviewMargins(descriptor.mediaPreviewMargins)
 , _api(&session().mtp())
 , _staticCount(_mode == Mode::Full ? kEmojiSectionCount : 1)
 , _premiumIcon(_mode == Mode::EmojiStatus
@@ -513,7 +518,7 @@ EmojiListWidget::EmojiListWidget(
 	if (_mode == Mode::ChannelStatus) {
 		session().api().peerPhoto().emojiListValue(
 			Api::PeerPhoto::EmojiListType::NoChannelStatus
-		) | rpl::start_with_next([=](const std::vector<DocumentId> &list) {
+		) | rpl::on_next([=](const std::vector<DocumentId> &list) {
 			_restrictedCustomList = { begin(list), end(list) };
 			if (!_custom.empty()) {
 				refreshCustom();
@@ -521,7 +526,7 @@ EmojiListWidget::EmojiListWidget(
 		}, lifetime());
 	} else if (_mode == Mode::EmojiStatus && _features.collectibleStatus) {
 		session().data().emojiStatuses().collectiblesUpdates(
-		) | rpl::start_with_next([=] {
+		) | rpl::on_next([=] {
 			refreshCustom();
 		}, lifetime());
 	}
@@ -538,12 +543,12 @@ EmojiListWidget::EmojiListWidget(
 	}
 
 	_picker->chosen(
-	) | rpl::start_with_next([=](EmojiChosen data) {
+	) | rpl::on_next([=](EmojiChosen data) {
 		colorChosen(data);
 	}, lifetime());
 
 	_picker->hidden(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		pickerHidden();
 	}, lifetime());
 
@@ -551,14 +556,14 @@ EmojiListWidget::EmojiListWidget(
 		Data::PeerUpdate::Flag::EmojiSet
 	) | rpl::filter([=](const Data::PeerUpdate &update) {
 		return (update.peer.get() == _megagroupSet);
-	}) | rpl::start_with_next([=] {
+	}) | rpl::on_next([=] {
 		refreshCustom();
 		resizeToWidth(width());
 	}, lifetime());
 
 	session().data().stickers().updated(
 		Data::StickersType::Emoji
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		refreshCustom();
 		resizeToWidth(width());
 	}, lifetime());
@@ -566,7 +571,7 @@ EmojiListWidget::EmojiListWidget(
 	rpl::combine(
 		Data::AmPremiumValue(&session()),
 		session().premiumPossibleValue()
-	) | rpl::skip(1) | rpl::start_with_next([=] {
+	) | rpl::skip(1) | rpl::on_next([=] {
 		refreshCustom();
 		resizeToWidth(width());
 	}, lifetime());
@@ -575,7 +580,7 @@ EmojiListWidget::EmojiListWidget(
 		rpl::empty
 	) | rpl::then(
 		style::PaletteChanged()
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		initButton(_add, tr::lng_stickers_featured_add(tr::now), false);
 		initButton(_unlock, tr::lng_emoji_featured_unlock(tr::now), true);
 		initButton(_restore, tr::lng_emoji_premium_restore(tr::now), true);
@@ -677,13 +682,55 @@ void EmojiListWidget::applyNextSearchQuery() {
 void EmojiListWidget::showPreview() {
 	if (const auto over = std::get_if<OverEmoji>(&_pressed)) {
 		if (const auto custom = lookupCustomEmoji(over)) {
-			const auto document = custom.document;
-			_show->showMediaPreview(document->stickerSetOrigin(), document);
+			showPreviewFor(custom.document);
 			_previewShown = true;
 		}
 	}
 }
 
+void EmojiListWidget::showPreviewFor(not_null<DocumentData*> document) {
+	if ((_mode == Mode::FullReactions || _mode == Mode::RecentReactions)
+		&& _mediaPreviewParent) {
+		ensureMediaPreview();
+		_mediaPreview->showPreview(document->stickerSetOrigin(), document);
+	} else {
+		_show->showMediaPreview(document->stickerSetOrigin(), document);
+	}
+}
+
+void EmojiListWidget::ensureMediaPreview() {
+	if (!_mediaPreviewParent) {
+		return;
+	}
+	if (_mediaPreview) {
+		_mediaPreview->raise();
+		return;
+	}
+	const auto controller = Core::App().findWindow(_show->toastParent());
+	const auto sessionController = controller
+		? controller->sessionController()
+		: nullptr;
+	if (sessionController) {
+		const auto tooSmall = _mediaPreviewParent->height()
+			< st::emojiPanEmojiPreviewMinHeight;
+		const auto parent = tooSmall
+			? sessionController->content()
+			: _mediaPreviewParent;
+		_mediaPreview = base::make_unique_q<Window::MediaPreviewWidget>(
+			parent,
+			sessionController);
+		if (!tooSmall) {
+			_mediaPreview->setCustomPadding(
+				st::emojiPanReactionsPreviewPadding);
+			_mediaPreview->setBackgroundMargins(_mediaPreviewMargins);
+			_mediaPreview->setCustomRadius(st::emojiPanEmojiPreviewRadius);
+		}
+		_mediaPreview->show();
+		_mediaPreview->setGeometry(parent->geometry());
+		_mediaPreview->raise();
+	}
+}
+
 std::vector<EmojiPtr> EmojiListWidget::collectPlainSearchResults() {
 	return SearchEmoji(_searchQuery, _searchEmoji);
 }
@@ -895,7 +942,7 @@ object_ptr<TabbedSelector::InnerFooter> EmojiListWidget::createFooter() {
 	_footer = result;
 
 	_footer->setChosen(
-	) | rpl::start_with_next([=](uint64 setId) {
+	) | rpl::on_next([=](uint64 setId) {
 		showSet(setId);
 	}, _footer->lifetime());
 
@@ -1016,7 +1063,7 @@ void EmojiListWidget::setColorAllForceRippled(bool force) {
 		_colorAllRippleForcedLifetime = style::PaletteChanged(
 		) | rpl::filter([=] {
 			return _colorAllRipple != nullptr;
-		}) | rpl::start_with_next([=] {
+		}) | rpl::on_next([=] {
 			_colorAllRipple->forceRepaint();
 		});
 		if (!_colorAllRipple) {
@@ -1261,7 +1308,7 @@ void EmojiListWidget::fillEmojiStatusMenu(
 		int section,
 		int index) {
 	const auto chosen = lookupCustomEmoji(index, section);
-	if (!chosen || chosen.collectible) {
+	if (!chosen) {
 		return;
 	}
 	const auto selectWith = [=](TimeId scheduled) {
@@ -1763,6 +1810,9 @@ void EmojiListWidget::mouseReleaseEvent(QMouseEvent *e) {
 	}
 
 	if (_previewShown) {
+		if (_mediaPreview) {
+			_mediaPreview->hidePreview();
+		}
 		_previewShown = false;
 		return;
 	} else if (v::is_null(_selected) || _selected != pressed) {
@@ -2104,7 +2154,7 @@ void EmojiListWidget::colorChosen(EmojiChosen data) {
 
 	const auto emoji = data.emoji;
 	auto &settings = Core::App().settings();
-	if (const auto button = std::get_if<OverButton>(&_pickerSelected)) {
+	if (v::is<OverButton>(_pickerSelected)) {
 		settings.saveAllEmojiVariants(emoji);
 		for (auto section = int(Section::People)
 			; section < _staticCount
@@ -2425,7 +2475,7 @@ Ui::Text::CustomEmoji *EmojiListWidget::resolveCustomRecent(
 	const auto &data = customId.data;
 	if (const auto document = std::get_if<RecentEmojiDocument>(&data)) {
 		return resolveCustomRecent(document->id);
-	} else if (const auto emoji = std::get_if<EmojiPtr>(&data)) {
+	} else if (v::is<EmojiPtr>(data)) {
 		return nullptr;
 	}
 	Unexpected("Custom recent emoji id.");
@@ -2739,11 +2789,8 @@ void EmojiListWidget::setSelected(OverState newSelected) {
 	} else if (_previewShown && _pressed != _selected) {
 		if (const auto over = std::get_if<OverEmoji>(&_selected)) {
 			if (const auto custom = lookupCustomEmoji(over)) {
-				const auto document = custom.document;
 				_pressed = _selected;
-				_show->showMediaPreview(
-					document->stickerSetOrigin(),
-					document);
+				showPreviewFor(custom.document);
 			}
 		}
 	}
