@@ -100,7 +100,9 @@ constexpr auto kRequestTimeLimit = 60 * crl::time(1000);
 			MTP_long(data.vpaid_message_stars().value_or_empty()),
 			(data.vsuggested_post()
 				? *data.vsuggested_post()
-				: MTPSuggestedPost()));
+				: MTPSuggestedPost()),
+			MTP_int(data.vschedule_repeat_period().value_or_empty()),
+			MTP_string(qs(data.vsummary_from_language().value_or_empty())));
 	});
 }
 
@@ -116,7 +118,7 @@ ScheduledMessages::ScheduledMessages(not_null<Main::Session*> session)
 	_session->data().itemRemoved(
 	) | rpl::filter([](not_null<const HistoryItem*> item) {
 		return item->isScheduled();
-	}) | rpl::start_with_next([=](not_null<const HistoryItem*> item) {
+	}) | rpl::on_next([=](not_null<const HistoryItem*> item) {
 		remove(item);
 	}, _lifetime);
 }
@@ -276,7 +278,9 @@ void ScheduledMessages::sendNowSimpleMessage(
 			MTPFactCheck(),
 			MTPint(), // report_delivery_until_date
 			MTPlong(), // paid_message_stars
-			MTPSuggestedPost()),
+			MTPSuggestedPost(),
+			MTPint(), // schedule_repeat_period
+			MTPstring()), // summary_from_language
 		localFlags,
 		NewMessageType::Unread);
 
@@ -483,7 +487,7 @@ void ScheduledMessages::request(not_null<History*> history) {
 		? countListHash(i->second)
 		: uint64(0);
 	request.requestId = _session->api().request(
-		MTPmessages_GetScheduledHistory(peer->input, MTP_long(hash))
+		MTPmessages_GetScheduledHistory(peer->input(), MTP_long(hash))
 	).done([=](const MTPmessages_Messages &result) {
 		parse(history, result);
 	}).fail([=] {
