@@ -1117,9 +1117,10 @@ void DocumentData::save(
 		if (!toFile.isEmpty()) {
 			if (!media->bytes().isEmpty()) {
 				QFile f(toFile);
-				f.open(QIODevice::WriteOnly);
-				f.write(media->bytes());
-				f.close();
+				if (f.open(QIODevice::WriteOnly)) {
+					f.write(media->bytes());
+					f.close();
+				}
 
 				setLocation(Core::FileLocation(toFile));
 				session().local().writeFileLocation(
@@ -1216,7 +1217,7 @@ void DocumentData::save(
 
 void DocumentData::handleLoaderUpdates() {
 	_loader->updates(
-	) | rpl::start_with_next_error_done([=] {
+	) | rpl::on_next_error_done([=] {
 		_owner->documentLoadProgress(this);
 	}, [=](FileLoader::Error error) {
 		using FailureReason = FileLoader::FailureReason;
