@@ -41,8 +41,10 @@ public:
 
 	[[nodiscard]] Session &owner() const;
 	[[nodiscard]] Main::Session &session() const;
+	[[nodiscard]] not_null<PeerData*> peer() const;
 	[[nodiscard]] not_null<History*> history() const;
-	[[nodiscard]] not_null<ChannelData*> channel() const;
+	[[nodiscard]] UserData *bot() const;
+	[[nodiscard]] ChannelData *channel() const;
 	[[nodiscard]] not_null<Dialogs::MainList*> topicsList();
 	[[nodiscard]] rpl::producer<> destroyed() const;
 	[[nodiscard]] auto topicDestroyed() const
