@@ -380,11 +380,11 @@ rpl::producer<bool> CanManageGroupCallValue(not_null<PeerData*> peer) {
 		return rpl::single(user->isSelf());
 	} else if (const auto chat = peer->asChat()) {
 		return chat->amCreator()
-			? (rpl::single(true) | rpl::type_erased())
+			? (rpl::single(true) | rpl::type_erased)
 			: AdminRightValue(chat, flag);
 	} else if (const auto channel = peer->asChannel()) {
 		return channel->amCreator()
-			? (rpl::single(true) | rpl::type_erased())
+			? (rpl::single(true) | rpl::type_erased)
 			: AdminRightValue(channel, flag);
 	}
 	return rpl::single(false);
@@ -558,7 +558,7 @@ rpl::producer<QImage> PeerUserpicImageValue(
 
 			if (loading && !state->waiting) {
 				peer->session().downloaderTaskFinished(
-				) | rpl::start_with_next(state->push, state->waiting);
+				) | rpl::on_next(state->push, state->waiting);
 			} else if (!loading && state->waiting) {
 				state->waiting.destroy();
 			}
@@ -578,7 +578,7 @@ rpl::producer<QImage> PeerUserpicImageValue(
 		peer->session().changes().peerFlagsValue(
 			peer,
 			PeerUpdate::Flag::Photo
-		) | rpl::start_with_next(state->push, result);
+		) | rpl::on_next(state->push, result);
 		return result;
 	};
 }
