@@ -287,6 +287,7 @@ private:
 	void updateLockUnlockPosition();
 	void updateSuggestions(anim::type animated);
 	void processSearchFocusChange();
+	void closeSuggestions();
 
 	[[nodiscard]] bool redirectToSearchPossible() const;
 	[[nodiscard]] bool redirectKeyToSearch(QKeyEvent *e) const;
@@ -331,7 +332,7 @@ private:
 
 	base::unique_qptr<Ui::RpWidget> _chatFilters;
 
-	Ui::SlideWrap<Ui::RpWidget> *_topBarSuggestion = nullptr;
+	QPointer<Ui::SlideWrap<Ui::RpWidget>> _topBarSuggestion;
 	rpl::event_stream<int> _topBarSuggestionHeightChanged;
 	rpl::event_stream<bool> _searchStateForTopBarSuggestion;
 	rpl::event_stream<bool> _openedFolderOrForumChanges;
