@@ -7,7 +7,6 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 */
 #include "history/view/controls/history_view_suggest_options.h"
 
-#include "base/event_filter.h"
 #include "base/unixtime.h"
 #include "boxes/star_gift_box.h"
 #include "chat_helpers/compose/compose_show.h"
@@ -21,7 +20,6 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "history/history_item.h"
 #include "history/history_item_components.h"
 #include "history/history_item_helpers.h"
-#include "info/channel_statistics/earn/earn_format.h"
 #include "info/channel_statistics/earn/earn_icons.h"
 #include "lang/lang_keys.h"
 #include "lottie/lottie_icon.h"
@@ -32,6 +30,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "ui/layers/generic_box.h"
 #include "ui/text/text_utilities.h"
 #include "ui/boxes/choose_date_time.h"
+#include "ui/boxes/emoji_stake_box.h"
 #include "ui/boxes/single_choice_box.h"
 #include "ui/controls/ton_common.h"
 #include "ui/widgets/fields/number_input.h"
@@ -75,19 +74,6 @@ namespace {
 	}));
 }
 
-[[nodiscard]] not_null<Ui::RpWidget*> AddMoneyInputIcon(
-		not_null<QWidget*> parent,
-		Ui::Text::PaletteDependentEmoji emoji) {
-	auto helper = Ui::Text::CustomEmojiHelper();
-	auto text = helper.paletteDependent(std::move(emoji));
-	return Ui::CreateChild<Ui::FlatLabel>(
-		parent,
-		rpl::single(std::move(text)),
-		st::defaultFlatLabel,
-		st::defaultPopupMenu,
-		helper.context());
-}
-
 } // namespace
 
 void ChooseSuggestTimeBox(
@@ -123,90 +109,6 @@ void ChooseSuggestTimeBox(
 	});
 }
 
-void AddApproximateUsd(
-		not_null<QWidget*> field,
-		not_null<Main::Session*> session,
-		rpl::producer<CreditsAmount> price) {
-	auto value = std::move(price) | rpl::map([=](CreditsAmount amount) {
-		if (!amount) {
-			return QString();
-		}
-		const auto appConfig = &session->appConfig();
-		const auto rate = amount.ton()
-			? appConfig->currencySellRate()
-			: (appConfig->starsSellRate() / 100.);
-		return Info::ChannelEarn::ToUsd(amount, rate, 2);
-	});
-	const auto usd = Ui::CreateChild<Ui::FlatLabel>(
-		field,
-		std::move(value),
-		st::suggestPriceEstimate);
-	const auto move = [=] {
-		usd->moveToRight(0, st::suggestPriceEstimateTop);
-	};
-	base::install_event_filter(field, [=](not_null<QEvent*> e) {
-		if (e->type() == QEvent::Resize) {
-			move();
-		}
-		return base::EventFilterResult::Continue;
-	});
-	usd->widthValue() | rpl::on_next(move, usd->lifetime());
-}
-
-not_null<Ui::NumberInput*> AddStarsInputField(
-		not_null<Ui::VerticalLayout*> container,
-		StarsInputFieldArgs &&args) {
-	const auto wrap = container->add(
-		object_ptr<Ui::FixedHeightWidget>(
-			container,
-			st::editTagField.heightMin),
-		st::boxRowPadding);
-	const auto result = Ui::CreateChild<Ui::NumberInput>(
-		wrap,
-		st::editTagField,
-		rpl::single(u"0"_q),
-		args.value ? QString::number(*args.value) : QString(),
-		args.max ? args.max : std::numeric_limits<int>::max());
-	const auto icon = AddMoneyInputIcon(
-		result,
-		Ui::Earn::IconCreditsEmoji());
-
-	wrap->widthValue() | rpl::on_next([=](int width) {
-		icon->move(st::starsFieldIconPosition);
-		result->move(0, 0);
-		result->resize(width, result->height());
-		wrap->resize(width, result->height());
-	}, wrap->lifetime());
-
-	return result;
-}
-
-not_null<Ui::InputField*> AddTonInputField(
-		not_null<Ui::VerticalLayout*> container,
-		TonInputFieldArgs &&args) {
-	const auto wrap = container->add(
-		object_ptr<Ui::FixedHeightWidget>(
-			container,
-			st::editTagField.heightMin),
-		st::boxRowPadding);
-	const auto result = Ui::CreateTonAmountInput(
-		wrap,
-		rpl::single('0' + Ui::TonAmountSeparator() + '0'),
-		args.value);
-	const auto icon = AddMoneyInputIcon(
-		result,
-		Ui::Earn::IconCurrencyEmoji());
-
-	wrap->widthValue() | rpl::on_next([=](int width) {
-		icon->move(st::tonFieldIconPosition);
-		result->move(0, 0);
-		result->resize(width, result->height());
-		wrap->resize(width, result->height());
-	}, wrap->lifetime());
-
-	return result;
-}
-
 StarsTonPriceInput AddStarsTonPriceInput(
 		not_null<Ui::VerticalLayout*> container,
 		StarsTonPriceArgs &&args) {
@@ -747,12 +649,12 @@ void ChooseSuggestPriceBox(
 						tr::now,
 						lt_count,
 						nanoTonMin / float64(Ui::kNanosInOne),
-						Ui::Text::RichLangValue)
+						tr::rich)
 					: tr::lng_gift_sell_min_price(
 						tr::now,
 						lt_count,
 						starsMin,
-						Ui::Text::RichLangValue));
+						tr::rich));
 			}
 			return;
 		}
@@ -763,7 +665,8 @@ void ChooseSuggestPriceBox(
 				state->savePending = true;
 				return;
 			} else if (credits->tonBalance() < value) {
-				box->uiShow()->show(Box(InsufficientTonBox, usePeer, value));
+				box->uiShow()->show(
+					Box(Ui::InsufficientTonBox, session, value));
 				return;
 			}
 		}
@@ -830,25 +733,25 @@ void ChooseSuggestPriceBox(
 		if (args.mode == SuggestMode::Change) {
 			return tr::lng_suggest_options_update(
 				tr::now,
-				Ui::Text::WithEntities);
+				tr::marked);
 		} else if (price.empty()) {
 			return tr::lng_suggest_options_offer_free(
 				tr::now,
-				Ui::Text::WithEntities);
+				tr::marked);
 		} else if (price.ton()) {
 			return tr::lng_suggest_options_offer(
 				tr::now,
 				lt_amount,
 				Ui::Text::IconEmoji(&st::tonIconEmoji).append(
 					Lang::FormatCreditsAmountDecimal(price)),
-				Ui::Text::WithEntities);
+				tr::marked);
 		}
 		return tr::lng_suggest_options_offer(
 			tr::now,
 			lt_amount,
 			Ui::Text::IconEmoji(&st::starIconEmoji).append(
 				Lang::FormatCreditsAmountDecimal(price)),
-			Ui::Text::WithEntities);
+			tr::marked);
 	}));
 	const auto buttonWidth = st::boxWidth
 		- rect::m::sum::h(st::suggestPriceBox.buttonPadding);
@@ -934,60 +837,6 @@ QString FormatAfterCommissionPercent(
 	return QString::number(mul / 10.) + '%';
 }
 
-void InsufficientTonBox(
-		not_null<Ui::GenericBox*> box,
-		not_null<PeerData*> peer,
-		CreditsAmount required) {
-	box->setStyle(st::suggestPriceBox);
-	box->addTopButton(st::boxTitleClose, [=] {
-		box->closeBox();
-	});
-
-	auto icon = Settings::CreateLottieIcon(
-		box->verticalLayout(),
-		{
-			.name = u"diamond"_q,
-			.sizeOverride = st::normalBoxLottieSize,
-		},
-		{});
-	box->setShowFinishedCallback([animate = std::move(icon.animate)] {
-		animate(anim::repeat::loop);
-	});
-	box->addRow(std::move(icon.widget), st::lowTonIconPadding);
-	const auto add = required - peer->session().credits().tonBalance();
-	const auto nano = add.whole() * Ui::kNanosInOne + add.nano();
-	const auto amount = Ui::FormatTonAmount(nano).full;
-	box->addRow(
-		object_ptr<Ui::FlatLabel>(
-			box,
-			tr::lng_suggest_low_ton_title(tr::now, lt_amount, amount),
-			st::boxTitle),
-		st::boxRowPadding + st::lowTonTitlePadding,
-		style::al_top);
-	const auto label = box->addRow(
-		object_ptr<Ui::FlatLabel>(
-			box,
-			tr::lng_suggest_low_ton_text(Ui::Text::RichLangValue),
-			st::lowTonText),
-		st::boxRowPadding + st::lowTonTextPadding,
-		style::al_top);
-	label->setTryMakeSimilarLines(true);
-	label->resizeToWidth(
-		st::boxWidth - st::boxRowPadding.left() - st::boxRowPadding.right());
-
-	const auto url = tr::lng_suggest_low_ton_fragment_url(tr::now);
-	const auto button = box->addButton(
-		tr::lng_suggest_low_ton_fragment(),
-		[=] { UrlClickHandler::Open(url); });
-	const auto buttonWidth = st::boxWidth
-		- rect::m::sum::h(st::suggestPriceBox.buttonPadding);
-	button->widthValue() | rpl::filter([=] {
-		return (button->widthNoMargins() != buttonWidth);
-	}) | rpl::on_next([=] {
-		button->resizeToWidth(buttonWidth);
-	}, button->lifetime());
-}
-
 SuggestOptionsBar::SuggestOptionsBar(
 	std::shared_ptr<ChatHelpers::Show> show,
 	not_null<PeerData*> peer,
