@@ -137,7 +137,7 @@ rpl::producer<Ui::RequestsBarContent> RequestsBarContentByPeer(
 				Data::PeerFlagValue(
 					channel,
 					ChannelData::Flag::Forum
-				) | rpl::start_with_next([=](bool hiddenByForum) {
+				) | rpl::on_next([=](bool hiddenByForum) {
 					if (hiddenByForum) {
 						consumer.put_next({});
 					} else {
@@ -150,7 +150,7 @@ rpl::producer<Ui::RequestsBarContent> RequestsBarContentByPeer(
 		peer->session().downloaderTaskFinished(
 		) | rpl::filter([=] {
 			return state->someUserpicsNotLoaded;
-		}) | rpl::start_with_next([=] {
+		}) | rpl::on_next([=] {
 			for (const auto &userpic : state->userpics) {
 				if (userpic.peer->userpicUniqueKey(userpic.view)
 					!= userpic.uniqueKey) {
@@ -165,7 +165,7 @@ rpl::producer<Ui::RequestsBarContent> RequestsBarContentByPeer(
 			peer
 		) | rpl::filter([=](int count) {
 			return (state->current.count != count);
-		}) | rpl::start_with_next([=](int count) {
+		}) | rpl::on_next([=](int count) {
 			const auto &requesters = peer->isChat()
 				? peer->asChat()->recentRequesters()
 				: peer->asChannel()->recentRequesters();
