@@ -77,7 +77,8 @@ bool CanScheduleUntilOnline(not_null<PeerData*> peer) {
 		return !user->isSelf()
 			&& !user->isBot()
 			&& !user->lastseen().isHidden()
-			&& !user->starsPerMessageChecked();
+			&& !user->starsPerMessageChecked()
+			&& !user->isNotificationsUser();
 	}
 	return false;
 }
@@ -135,10 +136,10 @@ void ScheduleBox(
 				tr::lng_schedule_repeat_promo(
 					tr::now,
 					lt_link,
-					Ui::Text::Link(
-						Ui::Text::Bold(
+					tr::link(
+						tr::bold(
 							tr::lng_schedule_repeat_promo_link(tr::now))),
-					Ui::Text::RichLangValue),
+					tr::rich),
 				u"schedule_repeat"_q);
 			return true;
 		};
