@@ -8,25 +8,34 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "history/view/history_view_translate_bar.h"
 
 #include "boxes/translate_box.h"
+#include "ui/boxes/about_cocoon_box.h"
+#include "chat_helpers/stickers_lottie.h"
 #include "core/application.h"
 #include "core/core_settings.h"
+#include "core/ui_integration.h"
+#include "data/stickers/data_custom_emoji.h"
 #include "data/data_changes.h"
+#include "data/data_document.h"
 #include "history/history.h"
 #include "lang/lang_keys.h"
 #include "main/main_session.h"
+#include "settings/settings_credits_graphics.h" // CreditsEntryBoxStyleOverrides
+#include "ui/widgets/labels.h"
+#include "ui/widgets/shadow.h"
 #include "ui/effects/ripple_animation.h"
 #include "ui/boxes/choose_language_box.h" // EditSkipTranslationLanguages.
 #include "ui/layers/box_content.h"
+#include "ui/layers/generic_box.h"
 #include "ui/widgets/menu/menu_item_base.h"
 #include "ui/text/text_utilities.h"
 #include "ui/toast/toast.h"
+#include "ui/widgets/menu/menu_multiline_action.h"
 #include "ui/widgets/buttons.h"
-#include "ui/widgets/labels.h"
 #include "ui/widgets/popup_menu.h"
-#include "ui/widgets/shadow.h"
 #include "ui/painter.h"
 #include "window/window_session_controller.h"
 #include "styles/style_chat.h"
+#include "styles/style_layers.h"
 #include "styles/style_menu_icons.h"
 
 #include <QtGui/QtEvents>
@@ -39,7 +48,7 @@ constexpr auto kToastDuration = 4 * crl::time(1000);
 class TwoTextAction final : public Ui::Menu::ItemBase {
 public:
 	TwoTextAction(
-		not_null<Ui::RpWidget*> parent,
+		not_null<Ui::Menu::Menu*> parent,
 		const style::Menu &st,
 		const QString &text1,
 		const QString &text2,
@@ -81,7 +90,7 @@ TextParseOptions MenuTextOptions = {
 };
 
 TwoTextAction::TwoTextAction(
-	not_null<Ui::RpWidget*> parent,
+	not_null<Ui::Menu::Menu*> parent,
 	const style::Menu &st,
 	const QString &text1,
 	const QString &text2,
@@ -89,7 +98,7 @@ TwoTextAction::TwoTextAction(
 	const style::icon *icon,
 	const style::icon *iconOver)
 : ItemBase(parent, st)
-, _dummyAction(new QAction(parent))
+, _dummyAction(Ui::CreateChild<QAction>(parent))
 , _st(st)
 , _icon(icon)
 , _iconOver(iconOver)
@@ -98,8 +107,8 @@ TwoTextAction::TwoTextAction(
 	+ _st.itemStyle.font->height
 	+ st::ttlItemTimerFont->height
 	+ st::ttlItemPadding.bottom()) {
-	initResizeHook(parent->sizeValue());
-	setClickedCallback(std::move(callback));
+	fitToMenuWidth();
+	setActionTriggered(std::move(callback));
 
 	paintRequest(
 	) | rpl::on_next([=] {
@@ -476,6 +485,36 @@ void TranslateBar::showMenu(base::unique_qptr<Ui::PopupMenu> menu) {
 		tr::lng_translate_menu_hide(tr::now),
 		hideBar,
 		&st::menuIconCancel);
+	_menu->addSeparator();
+
+	const auto cocoon = ChatHelpers::GenerateLocalTgsSticker(
+		&_history->session(),
+		u"cocoon"_q);
+	cocoon->overrideEmojiUsesTextColor(true);
+	auto item = base::make_unique_q<Ui::Menu::MultilineAction>(
+		_menu->menu(),
+		st::defaultMenu,
+		st::historyTranslateCocoonLabel,
+		QPoint(
+			st::defaultMenu.itemPadding.left(),
+			st::defaultMenu.itemPadding.top()),
+		tr::lng_translate_cocoon_menu(
+			tr::now,
+			lt_emoji,
+			Data::SingleCustomEmoji(cocoon),
+			lt_link,
+			tr::link(tr::lng_translate_cocoon_link(tr::now, tr::bold)),
+			tr::rich),
+		Core::TextContext({
+			.session = &_history->session(),
+			.customEmojiLoopLimit = -1,
+		}));
+	item->clicks(
+	) | rpl::on_next([controller = _controller] {
+		controller->show(Box(Ui::AboutCocoonBox));
+	}, item->lifetime());
+	_menu->addAction(std::move(item));
+
 	_menu->popup(_wrap.mapToGlobal(
 		QPoint(_wrap.width(), 0) + st::historyTranslateMenuPosition));
 }
@@ -487,8 +526,8 @@ void TranslateBar::showSettingsToast(
 	const auto text = tr::lng_translate_dont_added(
 		tr::now,
 		lt_name,
-		Ui::Text::Bold(Ui::LanguageName(ignored)),
-		Ui::Text::WithEntities);
+		tr::bold(Ui::LanguageName(ignored)),
+		tr::marked);
 	showToast(text, tr::lng_translate_settings(tr::now), [=] {
 		if (const auto strong = weak.get()) {
 			const auto box = strong->show(
@@ -513,7 +552,7 @@ void TranslateBar::showHiddenToast(not_null<PeerData*> peer) {
 		: peer->isBroadcast()
 		? tr::lng_translate_hidden_channel
 		: tr::lng_translate_hidden_group;
-	const auto proj = Ui::Text::WithEntities;
+	const auto proj = tr::marked;
 	showToast(phrase(tr::now, proj), tr::lng_translate_undo(tr::now), [=] {
 		peer->saveTranslationDisabled(false);
 	});
