@@ -757,7 +757,7 @@ void InnerWidget::setupEnd() {
 						.title = tr::lng_star_ref_ended_title(tr::now),
 						.text = tr::lng_star_ref_ended_text(
 							tr::now,
-							Ui::Text::RichLangValue),
+							tr::rich),
 						.duration = Ui::Toast::kDefaultDuration * 3,
 					});
 				}
@@ -778,7 +778,7 @@ object_ptr<Ui::RpWidget> InnerWidget::infoRow(
 	raw->add(
 		object_ptr<Ui::FlatLabel>(
 			raw,
-			std::move(title) | Ui::Text::ToBold(),
+			std::move(title) | rpl::map(tr::bold),
 			st::defaultFlatLabel),
 		st::settingsPremiumRowTitlePadding);
 	raw->add(
@@ -902,7 +902,7 @@ void Widget::restoreState(not_null<Memento*> memento) {
 
 std::unique_ptr<Ui::Premium::TopBarAbstract> Widget::setupTop() {
 	auto title = tr::lng_star_ref_title();
-	auto about = tr::lng_star_ref_about() | Ui::Text::ToWithEntities();
+	auto about = tr::lng_star_ref_about(tr::marked);
 
 	const auto controller = this->controller();
 	const auto weak = base::make_weak(controller->parentController());
@@ -1008,8 +1008,8 @@ std::unique_ptr<Ui::RpWidget> Widget::setupBottom() {
 				: tr::lng_star_ref_start_info)(
 					lt_terms,
 					tr::lng_star_ref_button_link(
-					) | Ui::Text::ToLink(tr::lng_star_ref_tos_url(tr::now)),
-					Ui::Text::WithEntities),
+						tr::url(tr::lng_star_ref_tos_url(tr::now))),
+					tr::marked),
 			st::boxDividerLabel),
 		QMargins(margins.left(), 0, margins.right(), 0));
 	save->setClickedCallback([=] {
@@ -1032,7 +1032,7 @@ std::unique_ptr<Ui::RpWidget> Widget::setupBottom() {
 						? tr::lng_star_ref_updated_text
 						: tr::lng_star_ref_created_text)(
 							tr::now,
-							Ui::Text::RichLangValue),
+							tr::rich),
 					.duration = Ui::Toast::kDefaultDuration * 3,
 				});
 			});
