@@ -429,7 +429,11 @@ MainWidget::MainWidget(
 	session().data().stickers().notifySavedGifsUpdated();
 }
 
-MainWidget::~MainWidget() = default;
+MainWidget::~MainWidget() {
+	if (_controller->activeChatCurrent()) {
+		session().api().saveCurrentDraftToCloud();
+	}
+}
 
 Main::Session &MainWidget::session() const {
 	return _controller->session();
@@ -1407,18 +1411,21 @@ void MainWidget::showHistory(
 		}
 		_stack.clear();
 	} else {
-		for (auto i = 0, s = int(_stack.size()); i < s; ++i) {
-			if (_stack.at(i)->type() == HistoryStackItem && _stack.at(i)->peer()->id == peerId) {
-				foundInStack = true;
-				while (int(_stack.size()) > i + 1) {
-					ClearBotStartToken(_stack.back()->peer());
+		if (!params.allowDuplicateInStack) {
+			for (auto i = 0, s = int(_stack.size()); i < s; ++i) {
+				if (_stack.at(i)->type() == HistoryStackItem
+					&& _stack.at(i)->peer()->id == peerId) {
+					foundInStack = true;
+					while (int(_stack.size()) > i + 1) {
+						ClearBotStartToken(_stack.back()->peer());
+						_stack.pop_back();
+					}
 					_stack.pop_back();
+					if (!back) {
+						back = true;
+					}
+					break;
 				}
-				_stack.pop_back();
-				if (!back) {
-					back = true;
-				}
-				break;
 			}
 		}
 		if (const auto activeChat = _controller->activeChatCurrent()) {
@@ -1994,23 +2001,23 @@ void MainWidget::showNonPremiumLimitToast(bool download) {
 				tr::now,
 				lt_percent,
 				TextWithEntities{ QString::number(percent - 100) },
-				Ui::Text::RichLangValue)
+				tr::rich)
 		: (download
 			? tr::lng_limit_download_increase_times
 			: tr::lng_limit_upload_increase_times)(
 				tr::now,
 				lt_count,
 				percent / 100,
-				Ui::Text::RichLangValue);
+				tr::rich);
 	auto text = (download
 		? tr::lng_limit_download_subscribe
 		: tr::lng_limit_upload_subscribe)(
 			tr::now,
 			lt_link,
-			Ui::Text::Link(Ui::Text::Bold(link)),
+			tr::link(tr::bold(link)),
 			lt_increase,
 			TextWithEntities{ increase },
-			Ui::Text::RichLangValue);
+			tr::rich);
 	auto filter = [=](ClickHandlerPtr handler, Qt::MouseButton button) {
 		Settings::ShowPremium(
 			controller(),
@@ -2892,7 +2899,7 @@ int MainWidget::backgroundFromY() const {
 
 bool MainWidget::contentOverlapped(const QRect &globalRect) {
 	return _history->contentOverlapped(globalRect)
-		|| _playerPlaylist->overlaps(globalRect);
+		/*|| _playerPlaylist->overlaps(globalRect)*/;
 }
 
 void MainWidget::activate() {
