@@ -46,12 +46,12 @@ MediaPreviewWidget::MediaPreviewWidget(
 , _emojiSize(Ui::Emoji::GetSizeLarge() / style::DevicePixelRatio()) {
 	setAttribute(Qt::WA_TransparentForMouseEvents);
 	_controller->session().downloaderTaskFinished(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		update();
 	}, lifetime());
 
 	style::PaletteChanged(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		if (_document && _document->emojiUsesTextColor()) {
 			_cache = QPixmap();
 		}
@@ -243,7 +243,10 @@ void MediaPreviewWidget::startShow() {
 				Window::GifPauseReason::MediaPreview);
 		}
 		_hiding = false;
-		_a_shown.start([=] { update(); }, 0., 1., st::stickerPreviewDuration);
+		const auto duration = _customDuration
+			? _customDuration
+			: st::stickerPreviewDuration;
+		_a_shown.start([=] { update(); }, 0., 1., duration);
 	} else {
 		update();
 	}
@@ -257,7 +260,10 @@ void MediaPreviewWidget::hidePreview() {
 		_cache = currentImage();
 	}
 	_hiding = true;
-	_a_shown.start([=] { update(); }, 1., 0., st::stickerPreviewDuration);
+	const auto duration = _customDuration
+		? _customDuration
+		: st::stickerPreviewDuration;
+	_a_shown.start([=] { update(); }, 1., 0., duration);
 	_photo = nullptr;
 	_photoMedia = nullptr;
 	_document = nullptr;
@@ -309,6 +315,10 @@ void MediaPreviewWidget::setCustomRadius(int radius) {
 	update();
 }
 
+void MediaPreviewWidget::setCustomDuration(crl::time duration) {
+	_customDuration = duration;
+}
+
 QSize MediaPreviewWidget::currentDimensions() const {
 	if (!_cachedSize.isEmpty()) {
 		return _cachedSize;
@@ -418,9 +428,9 @@ void MediaPreviewWidget::setupLottie() {
 		});
 	};
 
-	_lottie->updates() | rpl::start_with_next(handler, lifetime());
+	_lottie->updates() | rpl::on_next(handler, lifetime());
 	if (_effect) {
-		_effect->updates() | rpl::start_with_next(handler, lifetime());
+		_effect->updates() | rpl::on_next(handler, lifetime());
 	}
 }
 
