@@ -106,7 +106,6 @@ not_null<QAction*> Menu::insertAction(
 	const auto action = raw->action();
 	_actions.insert(begin(_actions) + position, action);
 
-	raw->setParent(this);
 	raw->show();
 	raw->setIndex(position);
 	for (auto i = position, to = int(_actionWidgets.size()); i != to; ++i) {
@@ -265,6 +264,19 @@ void Menu::resizeFromInner(int w, int h) {
 	}
 }
 
+QRect Menu::visibleRect() const {
+	return (_visibleBottom > _visibleTop)
+		? QRect(0, _visibleTop, width(), _visibleBottom - _visibleTop)
+		: rect();
+}
+
+void Menu::visibleTopBottomUpdated(
+		int visibleTop,
+		int visibleBottom) {
+	_visibleTop = visibleTop;
+	_visibleBottom = visibleBottom;
+}
+
 rpl::producer<> Menu::resizesFromInner() const {
 	return _resizesFromInner.events();
 }
@@ -284,6 +296,13 @@ const std::vector<not_null<QAction*>> &Menu::actions() const {
 	return _actions;
 }
 
+ItemBase *Menu::itemForAction(not_null<QAction*> action) const {
+	const auto i = ranges::find(_actions, action);
+	return (i != end(_actions))
+		? _actionWidgets[std::distance(begin(_actions), i)].get()
+		: nullptr;
+}
+
 void Menu::setForceWidth(int forceWidth) {
 	_forceWidth = forceWidth;
 	resizeFromInner(_forceWidth, height());
@@ -399,7 +418,8 @@ void Menu::mouseMoveEvent(QMouseEvent *e) {
 
 void Menu::handleMouseMove(QPoint globalPosition) {
 	const auto margins = style::margins(0, _st.skip, 0, _st.skip);
-	const auto inner = rect().marginsRemoved(margins);
+	const auto visible = visibleRect();
+	const auto inner = rect().marginsRemoved(margins).intersected(visible);
 	const auto localPosition = mapFromGlobal(globalPosition);
 	if (inner.contains(localPosition)) {
 		updateSelected(globalPosition);
@@ -422,7 +442,8 @@ void Menu::mouseReleaseEvent(QMouseEvent *e) {
 void Menu::handleMousePress(QPoint globalPosition) {
 	handleMouseMove(globalPosition);
 	const auto margins = style::margins(0, _st.skip, 0, _st.skip);
-	const auto inner = rect().marginsRemoved(margins);
+	const auto visible = visibleRect();
+	const auto inner = rect().marginsRemoved(margins).intersected(visible);
 	const auto localPosition = mapFromGlobal(globalPosition);
 	const auto pressed = (inner.contains(localPosition)
 		&& _lastSelectedByMouse)
@@ -438,10 +459,26 @@ void Menu::handleMousePress(QPoint globalPosition) {
 }
 
 void Menu::handleMouseRelease(QPoint globalPosition) {
-	if (!rect().contains(mapFromGlobal(globalPosition))
-			&& _mouseReleaseDelegate) {
+	if (_pressedOutside) {
+		_pressedOutside = false;
+		updateSelected(globalPosition);
+		if (const auto selected = findSelectedAction()) {
+			selected->setClicked(TriggeredSource::Mouse);
+		}
+		return;
+	}
+	const auto margins = style::margins(0, _st.skip, 0, _st.skip);
+	const auto visible = visibleRect();
+	const auto inner = rect().marginsRemoved(margins).intersected(visible);
+	if (!inner.contains(mapFromGlobal(globalPosition))
+		&& _mouseReleaseDelegate) {
 		_mouseReleaseDelegate(globalPosition);
 	}
 }
 
+void Menu::handlePressedOutside(QPoint globalPosition) {
+	_pressedOutside = true;
+	updateSelected(globalPosition);
+}
+
 } // namespace Ui::Menu
