@@ -17,19 +17,6 @@ namespace Ui::Menu {
 
 MenuCallback CreateAddActionCallback(not_null<Ui::PopupMenu*> menu) {
 	return MenuCallback([=](MenuCallback::Args a) -> QAction* {
-		const auto initFilter = [&](not_null<Ui::Menu::ItemBase*> action) {
-			if (const auto copy = a.triggerFilter) {
-				action->setClickedCallback([=] {
-					const auto weak = base::make_weak(action);
-					if (copy() && weak && !action->isDisabled()) {
-						action->setDisabled(true);
-						crl::on_main(
-							weak,
-							[=] { action->setDisabled(false); });
-					}
-				});
-			}
-		};
 		if (a.hideRequests) {
 			std::move(
 				a.hideRequests
@@ -54,31 +41,16 @@ MenuCallback CreateAddActionCallback(not_null<Ui::PopupMenu*> menu) {
 		} else if (a.separatorSt || a.isSeparator) {
 			return menu->addSeparator(a.separatorSt);
 		} else if (a.isAttention) {
-			auto owned = base::make_unique_q<Ui::Menu::Action>(
-				menu,
-				a.icon ? st::menuWithIconsAttention : st::menuAttention,
+			return menu->addAction(base::make_unique_q<Ui::Menu::Action>(
+				menu->menu(),
+				st::menuWithIconsAttention,
 				Ui::Menu::CreateAction(
 					menu->menu().get(),
 					a.text,
 					std::move(a.handler)),
 				a.icon,
-				a.icon);
-			initFilter(owned.get());
-			return menu->addAction(std::move(owned));
-		} else if (a.triggerFilter) {
-			auto owned = base::make_unique_q<Ui::Menu::Action>(
-				menu,
-				menu->st().menu,
-				Ui::Menu::CreateAction(
-					menu->menu().get(),
-					a.text,
-					std::move(a.handler)),
-				a.icon,
-				a.icon);
-			initFilter(owned.get());
-			return menu->addAction(std::move(owned));
+				a.icon));
 		} else if (auto owned = a.make ? a.make(menu) : nullptr) {
-			initFilter(owned.get());
 			return menu->addAction(std::move(owned));
 		}
 		return menu->addAction(a.text, std::move(a.handler), a.icon);
@@ -87,19 +59,6 @@ MenuCallback CreateAddActionCallback(not_null<Ui::PopupMenu*> menu) {
 
 MenuCallback CreateAddActionCallback(not_null<Ui::DropdownMenu*> menu) {
 	return MenuCallback([=](MenuCallback::Args a) -> QAction* {
-		const auto initFilter = [&](not_null<Ui::Menu::Action*> action) {
-			if (const auto copy = a.triggerFilter) {
-				action->setClickedCallback([=] {
-					const auto weak = base::make_weak(action);
-					if (copy() && weak && !action->isDisabled()) {
-						action->setDisabled(true);
-						crl::on_main(
-							weak,
-							[=] { action->setDisabled(false); });
-					}
-				});
-			}
-		};
 		if (a.hideRequests) {
 			Unexpected("Dropdown menu does not support hideRequests.");
 		// 	std::move(
@@ -126,7 +85,7 @@ MenuCallback CreateAddActionCallback(not_null<Ui::DropdownMenu*> menu) {
 			return menu->addSeparator(a.separatorSt);
 		} else if (a.isAttention) {
 			auto owned = base::make_unique_q<Ui::Menu::Action>(
-				menu,
+				menu->menu(),
 				a.icon ? st::menuWithIconsAttention : st::menuAttention,
 				Ui::Menu::CreateAction(
 					menu->menu().get(),
@@ -134,21 +93,7 @@ MenuCallback CreateAddActionCallback(not_null<Ui::DropdownMenu*> menu) {
 					std::move(a.handler)),
 				a.icon,
 				a.icon);
-			initFilter(owned.get());
 			return menu->addAction(std::move(owned));
-		} else if (a.triggerFilter) {
-			Unexpected("Dropdown menu does not support triggerFilter.");
-			// auto owned = base::make_unique_q<Ui::Menu::Action>(
-			// 	menu,
-			// 	menu->st().menu,
-			// 	Ui::Menu::CreateAction(
-			// 		menu->menu().get(),
-			// 		a.text,
-			// 		std::move(a.handler)),
-			// 	a.icon,
-			// 	a.icon);
-			// initFilter(owned.get());
-			// return menu->addAction(std::move(owned));
 		}
 		return menu->addAction(a.text, std::move(a.handler), a.icon);
 	});
