@@ -33,7 +33,7 @@ base::options::toggle OptionWebviewDebugEnabled({
 
 base::options::toggle OptionWebviewLegacyEdge({
 	.id = kOptionWebviewLegacyEdge,
-	.name = "Force legacy Edge WebView.",
+	.name = "Force legacy Edge WebView",
 	.description = "Skip modern CoreWebView2 check and force using legacy Edge WebView on Windows.",
 	.scope = base::options::windows,
 	.restartRequired = true,
